Welcome to the Hydrofunctions |version| Users Guide!
====================================================

.. toctree::
   :maxdepth: 2

   introduction
   installation
   notebooks/Writing_Valid_Requests_for_NWIS
   notebooks/Saving_Data
   notebooks/Selecting_Sites
   notebooks/viewing
   graphing
   notebooks/Site_File
   notebooks/Data_Catalog
   notebooks/Peak_Discharge
   notebooks/USGS_Statistics_Service
   contributing
   authors
   history
   hydrofunctions




Example Applications
====================

.. toctree::
   :maxdepth: 2
   :caption: Example Applications

   notebooks/Comparing_Urban_and_Rural_Streams
   notebooks/Hydrofunctions_nested_watersheds
   notebooks/Hydrofunctions_Comparing_Stream_Environments
   notebooks/DailyMean_vs_Instant
   notebooks/Hysteresis
   notebooks/Draw_Map_Demo
   notebooks/Graphing
   notebooks/Hydrofunctions_Tutorial





Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
